import java.util.Arrays;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.IntStream;
import java.util.stream.Stream;

import entities.Product;

public class StreamIntermediates {

	public static void main(String[] args) {
		List<String> words = Arrays.asList(new String[] { "hello", "hola", "hallo", "ciao" });
		Stream<String> stream = words.stream();
		stream.forEach(System.out::println);

		Stream<String> s = Stream.of("m", "k", "c", "t").sorted().limit(3);
		s.forEach(System.out::println);

		int[] digits = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
		IntStream is = IntStream.of(digits);
		System.out.println(is.count());
		System.out.println(IntStream.of(digits).findFirst()); // An exception is
																// thrown

		words = Arrays.asList("hello", null, "");
		words.stream().filter(t -> t != null) // ["hello", ""]
				.filter(t -> !t.isEmpty()) // ["hello"]
				.forEach(System.out::println);

		IntStream stream2 = IntStream.of(1, 2, 3, 4, 5, 6, 7);
		System.out.println(stream2.anyMatch(i -> i % 3 == 0));

		List<Integer> list = Arrays.asList(57, 38, 37, 54, 2);
		list.stream().sorted().forEach(System.out::println);

		List<String> strings = Arrays.asList("Stream", "Operations", "on", "Collections");
		strings.stream().min(Comparator.comparing((String x) -> x.length())).ifPresent(System.out::println);

		int reducedParams = Stream.of(1, 2, 3).reduce(0, (a, b) -> a + b);
		System.out.println(reducedParams);
		
		List<Product> productList = Arrays.asList(new Product(23, "potatoes"),
				  new Product(14, "orange"), new Product(13, "lemon"),
				  new Product(23, "bread"), new Product(13, "sugar"));
		productList.stream().map(Product::getName).forEach(System.out::println);
		List<String> collectorCollection = 
				  productList.stream().map(Product::getName).collect(Collectors.toList());
		for(String str : collectorCollection) {
			System.out.println(str);
		}
	}

}
